==> spip_3.2.11.orig.tar.xz: plugins-dist/dump/lang/dump_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucune_donnee' => 'Kéng Daten am Fichier.',
	'avis_probleme_ecriture_fichier' => 'De Fichier @fichier@ ka net geschriwwe ginn',

	// B
	'bouton_restaurer_base' => 'Datebank zeréckspillen',

	// C
	'confirmer_ecraser_base' => 'Jo, ech wëll meng Datebank duerch dëse Backup ersetzen',
	'confirmer_ecraser_tables_selection' => 'Jo, ech wëll déi ausgewielten Tafelen duerch dëse Backup ersetzen',

	// D
	'details_sauvegarde' => 'Detailer vun dem Backup:',

	// E
	'erreur_aucune_donnee_restauree' => 'Kéng Informatiounen zeréckgespillt',
	'erreur_connect_dump' => 'Et gëtt schon e Server "@dump@". Gitt ëm en anere Numm.',
	'erreur_creation_base_sqlite' => 'Onméiglech eng SQLite-Datebank fir de Backup bäizeflécken',
	'erreur_nom_fichier' => 'Dëse Fichiers-Numm ass nët erlaabt',
	'erreur_restaurer_verifiez' => 'Verbessert de Fehler fir kënnen zeréckzespillen.',
	'erreur_sauvegarde_deja_en_cours' => 'Et leeft schon e Backup',
	'erreur_sqlite_indisponible' => 'Onméiglech en SQLite-Backup bei ärem Provider bäizeflécken',
	'erreur_table_absente' => 'D’Tafel @table@ feelt',
	'erreur_table_donnees_manquantes' => 'Tafel @table@, Date feelen',
	'erreur_taille_sauvegarde' => 'De Backup schéngt net fonctionnéiert ze hunn. De Fichier @fichier@ ass eidel oder feelt.',

	// I
	'info_aucune_sauvegarde_trouvee' => 'Kee Backup fonnt',
	'info_restauration_finie' => 'Et ass fäerdeg! De Backup @archive@ ass op äre Site zeréckgespillt ginn. Dir kënnt',
	'info_restauration_sauvegarde' => 'Restauratioun vum Backup @archive@',
	'info_sauvegarde' => 'Backup',
	'info_sauvegarde_reussi_02' => 'De Backup vun der Datebank ass @archive@. Dir kënnt',
	'info_sauvegarde_reussi_03' => 'zeréck bei d’Gestioun',
	'info_sauvegarde_reussi_04' => 'vun ärem Site.',
	'info_selection_sauvegarde' => 'Dir wëllt de Backup @fichier@ zeréckspillen. Dës Operatioun ka net réckgängeg gemaach ginn.',

	// L
	'label_nom_fichier_restaurer' => 'Oder gitt de Numm vum Fichier un dee soll zeréckgespillt ginn',
	'label_nom_fichier_sauvegarde' => 'Numm vum Backup-Fichier',
	'label_selectionnez_fichier' => 'Wielt e Fichier aus der Lëscht',

	// N
	'nb_donnees' => '@nb@ Zeilen',

	// R
	'restauration_en_cours' => 'Zeréckspille leeft',

	// S
	'sauvegarde_en_cours' => 'Backup leeft',
	'sauvegardes_existantes' => 'Backups',
	'selectionnez_table_a_restaurer' => 'Wielt d’Tafelen aus déi sollen zeréckgespillt ginn',

	// T
	'texte_admin_tech_01' => 'Dës Optioun erlaabt den Inhalt vun der Datebank am Dossier @dossier@ ze späicheren. Vergiesst net och de ganzen Inhalt vum Dossier @img@ erofzelueden, wou d’Biller an d’Dokumenter vun den Artikelen an de Rubrike sinn.',
	'texte_admin_tech_02' => 'Opgepasst: dëse Backup ka nëmmen op e Site mat därselwechter SPIP-Versioun zeréckgespillt ginn. Dir däerft also ni "Datebank eidel maachen" an der Hoffnung dir kinnt se no engem Update nei installéieren... Kuckt <a href="@spipnet@">an der SPIP-Beschreiwung</a>.',
	'texte_restaurer_base' => 'E Backup zeréckspillen',
	'texte_restaurer_sauvegarde' => 'Dës Fonctioun erlaabt d’Zeréckspillen vun engem Backup vun der Datebank. Duerfir muss de Backup-Fichier am Dossier @dossier@ sinn. Passt op mat dëser Prozedur: <b>d’Ännerungen kënne net réckgängeg gemaach ginn.</b>',
	'texte_sauvegarde' => 'E Backup vun der Datebank maachen',
	'texte_sauvegarde_base' => 'Backup vun der Datebank maachen',
	'tout_restaurer' => 'All d’Tafelen zeréckspillen',
	'tout_sauvegarder' => 'Backup vun allen Tafelen',

	// U
	'une_donnee' => '1 Zeil'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// A
	'aucune_donnee' => 'Kéng Daten am Fichier.',
	'avis_probleme_ecriture_fichier' => 'De Fichier @fichier@ ka net geschriwwe ginn',

	// B
	'bouton_restaurer_base' => 'Datebank zeréckspillen',

	// C
	'confirmer_ecraser_base' => 'Jo, ech wëll meng Datebank duerch dëse Backup ersetzen',
	'confirmer_ecraser_tables_selection' => 'Jo, ech wëll déi ausgewielten Tafelen duerch dëse Backup ersetzen',

	// D
	'details_sauvegarde' => 'Detailer vun dem Backup:',

	// E
	'erreur_aucune_donnee_restauree' => 'Kéng Informatiounen zeréckgespillt',
	'erreur_connect_dump' => 'Et gëtt schon e Server "@dump@". Gitt ëm en anere Numm.',
	'erreur_creation_base_sqlite' => 'Onméiglech eng SQLite-Datebank fir de Backup bäizeflécken',
	'erreur_nom_fichier' => 'Dëse Fichiers-Numm ass nët erlaabt',
	'erreur_restaurer_verifiez' => 'Verbessert de Fehler fir kënnen zeréckzespillen.',
	'erreur_sauvegarde_deja_en_cours' => 'Et leeft schon e Backup',
	'erreur_sqlite_indisponible' => 'Onméiglech en SQLite-Backup bei ärem Provider bäizeflécken',
	'erreur_table_absente' => 'D’Tafel @table@ feelt',
	'erreur_table_donnees_manquantes' => 'Tafel @table@, Date feelen',
	'erreur_taille_sauvegarde' => 'De Backup schéngt net fonctionnéiert ze hunn. De Fichier @fichier@ ass eidel oder feelt.',

	// I
	'info_aucune_sauvegarde_trouvee' => 'Kee Backup fonnt',
	'info_restauration_finie' => 'Et ass fäerdeg! De Backup @archive@ ass op äre Site zeréckgespillt ginn. Dir kënnt',
	'info_restauration_sauvegarde' => 'Restauratioun vum Backup @archive@',
	'info_sauvegarde' => 'Backup',
	'info_sauvegarde_reussi_02' => 'De Backup vun der Datebank ass @archive@. Dir kënnt',
	'info_sauvegarde_reussi_03' => 'zeréck bei d’Gestioun',
	'info_sauvegarde_reussi_04' => 'vun ärem Site.',
	'info_selection_sauvegarde' => 'Dir wëllt de Backup @fichier@ zeréckspillen. Dës Operatioun ka net réckgängeg gemaach ginn.',

	// L
	'label_nom_fichier_restaurer' => 'Oder gitt de Numm vum Fichier un dee soll zeréckgespillt ginn',
	'label_nom_fichier_sauvegarde' => 'Numm vum Backup-Fichier',
	'label_selectionnez_fichier' => 'Wielt e Fichier aus der Lëscht',

	// N
	'nb_donnees' => '@nb@ Zeilen',

	// R
	'restauration_en_cours' => 'Zeréckspille leeft',

	// S
	'sauvegarde_en_cours' => 'Backup leeft',
	'sauvegardes_existantes' => 'Backups',
	'selectionnez_table_a_restaurer' => 'Wielt d’Tafelen aus déi sollen zeréckgespillt ginn',

	// T
	'texte_admin_tech_01' => 'Dës Optioun erlaabt den Inhalt vun der Datebank am Dossier @dossier@ ze späicheren. Vergiesst net och de ganzen Inhalt vum Dossier @img@ erofzelueden, wou d’Biller an d’Dokumenter vun den Artikelen an de Rubrike sinn.',
	'texte_admin_tech_02' => 'Opgepasst: dëse Backup ka nëmmen op e Site mat därselwechter SPIP-Versioun zeréckgespillt ginn. Dir däerft also ni "Datebank eidel maachen" an der Hoffnung dir kinnt se no engem Update nei installéieren... Kuckt <a href="@spipnet@">an der SPIP-Beschreiwung</a>.',
	'texte_restaurer_base' => 'E Backup zeréckspillen',
	'texte_restaurer_sauvegarde' => 'Dës Fonctioun erlaabt d’Zeréckspillen vun engem Backup vun der Datebank. Duerfir muss de Backup-Fichier am Dossier @dossier@ sinn. Passt op mat dëser Prozedur: <b>d’Ännerungen kënne net réckgängeg gemaach ginn.</b>',
	'texte_sauvegarde' => 'E Backup vun der Datebank maachen',
	'texte_sauvegarde_base' => 'Backup vun der Datebank maachen',
	'tout_restaurer' => 'All d’Tafelen zeréckspillen',
	'tout_sauvegarder' => 'Backup vun allen Tafelen',

	// U
	'une_donnee' => '1 Zeil',
];
